/* Instance.c generated by valac 0.56.19, the Vala compiler
 * generated from Instance.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_INSTANCE (tuba_api_instance_get_type ())
#define TUBA_API_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_INSTANCE, TubaAPIInstance))
#define TUBA_API_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_INSTANCE, TubaAPIInstanceClass))
#define TUBA_API_IS_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_INSTANCE))
#define TUBA_API_IS_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_INSTANCE))
#define TUBA_API_INSTANCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_INSTANCE, TubaAPIInstanceClass))

typedef struct _TubaAPIInstance TubaAPIInstance;
typedef struct _TubaAPIInstanceClass TubaAPIInstanceClass;
typedef struct _TubaAPIInstancePrivate TubaAPIInstancePrivate;

#define TUBA_API_INSTANCE_TYPE_URLS (tuba_api_instance_urls_get_type ())
#define TUBA_API_INSTANCE_URLS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrls))
#define TUBA_API_INSTANCE_URLS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrlsClass))
#define TUBA_API_INSTANCE_IS_URLS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_TYPE_URLS))
#define TUBA_API_INSTANCE_IS_URLS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_TYPE_URLS))
#define TUBA_API_INSTANCE_URLS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrlsClass))

typedef struct _TubaAPIInstanceUrls TubaAPIInstanceUrls;
typedef struct _TubaAPIInstanceUrlsClass TubaAPIInstanceUrlsClass;

#define TUBA_API_MASTODON_TYPE_CONFIGURATIONS (tuba_api_mastodon_configurations_get_type ())
#define TUBA_API_MASTODON_CONFIGURATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurations))
#define TUBA_API_MASTODON_CONFIGURATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurationsClass))
#define TUBA_API_MASTODON_IS_CONFIGURATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS))
#define TUBA_API_MASTODON_IS_CONFIGURATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_TYPE_CONFIGURATIONS))
#define TUBA_API_MASTODON_CONFIGURATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurationsClass))

typedef struct _TubaAPIMastodonConfigurations TubaAPIMastodonConfigurations;
typedef struct _TubaAPIMastodonConfigurationsClass TubaAPIMastodonConfigurationsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS (tuba_api_mastodon_configuration_polls_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_POLLS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))

typedef struct _TubaAPIMastodonConfigurationPolls TubaAPIMastodonConfigurationPolls;
typedef struct _TubaAPIMastodonConfigurationPollsClass TubaAPIMastodonConfigurationPollsClass;

#define TUBA_API_PLEROMA_TYPE_INSTANCE (tuba_api_pleroma_instance_get_type ())
#define TUBA_API_PLEROMA_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstance))
#define TUBA_API_PLEROMA_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstanceClass))
#define TUBA_API_PLEROMA_IS_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE))
#define TUBA_API_PLEROMA_IS_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_PLEROMA_TYPE_INSTANCE))
#define TUBA_API_PLEROMA_INSTANCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstanceClass))

typedef struct _TubaAPIPleromaInstance TubaAPIPleromaInstance;
typedef struct _TubaAPIPleromaInstanceClass TubaAPIPleromaInstanceClass;

#define TUBA_API_INSTANCE_TYPE_RULE (tuba_api_instance_rule_get_type ())
#define TUBA_API_INSTANCE_RULE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRule))
#define TUBA_API_INSTANCE_RULE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRuleClass))
#define TUBA_API_INSTANCE_IS_RULE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_TYPE_RULE))
#define TUBA_API_INSTANCE_IS_RULE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_TYPE_RULE))
#define TUBA_API_INSTANCE_RULE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRuleClass))

typedef struct _TubaAPIInstanceRule TubaAPIInstanceRule;
typedef struct _TubaAPIInstanceRuleClass TubaAPIInstanceRuleClass;

#define TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS (tuba_api_instance_v2_configuration_accounts_char_limits_get_type ())
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimits))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_ACCOUNTS_CHAR_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_IS_ACCOUNTS_CHAR_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS))
#define TUBA_API_INSTANCE_V2_CONFIGURATION_ACCOUNTS_CHAR_LIMITS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass))

typedef struct _TubaAPIInstanceV2ConfigurationAccountsCharLimits TubaAPIInstanceV2ConfigurationAccountsCharLimits;
typedef struct _TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass TubaAPIInstanceV2ConfigurationAccountsCharLimitsClass;
enum  {
	TUBA_API_INSTANCE_0_PROPERTY,
	TUBA_API_INSTANCE_URI_PROPERTY,
	TUBA_API_INSTANCE_TITLE_PROPERTY,
	TUBA_API_INSTANCE_THUMBNAIL_PROPERTY,
	TUBA_API_INSTANCE_VERSION_PROPERTY,
	TUBA_API_INSTANCE_URLS_PROPERTY,
	TUBA_API_INSTANCE_LANGUAGES_PROPERTY,
	TUBA_API_INSTANCE_CONFIGURATION_PROPERTY,
	TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY,
	TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY,
	TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY,
	TUBA_API_INSTANCE_PLEROMA_PROPERTY,
	TUBA_API_INSTANCE_RULES_PROPERTY,
	TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY,
	TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY,
	TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY,
	TUBA_API_INSTANCE_SUPPORTS_QUOTE_POSTING_PROPERTY,
	TUBA_API_INSTANCE_SUPPORTS_BUBBLE_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_SUPPORTED_MIME_TYPES_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_MAX_FIELDS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_NAME_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_VALUE_LENGTH_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_MAX_MEDIA_ATTACHMENTS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_CHARACTERS_RESERVED_PER_URL_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_MAX_CHARACTERS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_MAX_IMAGE_SIZE_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_MAX_VIDEO_SIZE_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_POLLS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_OPTIONS_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MIN_EXPIRATION_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_EXPIRATION_PROPERTY,
	TUBA_API_INSTANCE_COMPAT_STATUS_REACTIONS_MAX_PROPERTY,
	TUBA_API_INSTANCE_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_properties[TUBA_API_INSTANCE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA (tuba_api_pleroma_instance_metadata_get_type ())
#define TUBA_API_PLEROMA_INSTANCE_METADATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA, TubaAPIPleromaInstanceMetadata))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA, TubaAPIPleromaInstanceMetadataClass))
#define TUBA_API_PLEROMA_INSTANCE_IS_METADATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA))
#define TUBA_API_PLEROMA_INSTANCE_IS_METADATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_PLEROMA_INSTANCE_TYPE_METADATA, TubaAPIPleromaInstanceMetadataClass))

typedef struct _TubaAPIPleromaInstanceMetadata TubaAPIPleromaInstanceMetadata;
typedef struct _TubaAPIPleromaInstanceMetadataClass TubaAPIPleromaInstanceMetadataClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS (tuba_api_instance_v2_api_versions_get_type ())
#define TUBA_API_INSTANCE_V2_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))

typedef struct _TubaAPIInstanceV2APIVersions TubaAPIInstanceV2APIVersions;
typedef struct _TubaAPIInstanceV2APIVersionsClass TubaAPIInstanceV2APIVersionsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES (tuba_api_mastodon_configuration_statuses_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatuses))
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatusesClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES))
#define TUBA_API_MASTODON_CONFIGURATION_IS_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES))
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatusesClass))

typedef struct _TubaAPIMastodonConfigurationStatuses TubaAPIMastodonConfigurationStatuses;
typedef struct _TubaAPIMastodonConfigurationStatusesClass TubaAPIMastodonConfigurationStatusesClass;

#define TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS (tuba_api_pleroma_instance_metadata_field_limits_get_type ())
#define TUBA_API_PLEROMA_INSTANCE_METADATA_FIELD_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS, TubaAPIPleromaInstanceMetadataFieldLimits))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_FIELD_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS, TubaAPIPleromaInstanceMetadataFieldLimitsClass))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_IS_FIELD_LIMITS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_IS_FIELD_LIMITS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS))
#define TUBA_API_PLEROMA_INSTANCE_METADATA_FIELD_LIMITS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_PLEROMA_INSTANCE_METADATA_TYPE_FIELD_LIMITS, TubaAPIPleromaInstanceMetadataFieldLimitsClass))

typedef struct _TubaAPIPleromaInstanceMetadataFieldLimits TubaAPIPleromaInstanceMetadataFieldLimits;
typedef struct _TubaAPIPleromaInstanceMetadataFieldLimitsClass TubaAPIPleromaInstanceMetadataFieldLimitsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS (tuba_api_mastodon_configuration_media_attachments_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachments))
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachmentsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachmentsClass))

typedef struct _TubaAPIMastodonConfigurationMediaAttachments TubaAPIMastodonConfigurationMediaAttachments;
typedef struct _TubaAPIMastodonConfigurationMediaAttachmentsClass TubaAPIMastodonConfigurationMediaAttachmentsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS (tuba_api_mastodon_configuration_reactions_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactions))
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactionsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS))
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactionsClass))

typedef struct _TubaAPIMastodonConfigurationReactions TubaAPIMastodonConfigurationReactions;
typedef struct _TubaAPIMastodonConfigurationReactionsClass TubaAPIMastodonConfigurationReactionsClass;
typedef struct _TubaAPIInstanceRulePrivate TubaAPIInstanceRulePrivate;
enum  {
	TUBA_API_INSTANCE_RULE_0_PROPERTY,
	TUBA_API_INSTANCE_RULE_ID_PROPERTY,
	TUBA_API_INSTANCE_RULE_TEXT_PROPERTY,
	TUBA_API_INSTANCE_RULE_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_rule_properties[TUBA_API_INSTANCE_RULE_NUM_PROPERTIES];
typedef struct _TubaAPIInstanceUrlsPrivate TubaAPIInstanceUrlsPrivate;
enum  {
	TUBA_API_INSTANCE_URLS_0_PROPERTY,
	TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY,
	TUBA_API_INSTANCE_URLS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_instance_urls_properties[TUBA_API_INSTANCE_URLS_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIInstance {
	TubaEntity parent_instance;
	TubaAPIInstancePrivate * priv;
};

struct _TubaAPIInstanceClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstancePrivate {
	gchar* _uri;
	gchar* _title;
	gchar* _thumbnail;
	gchar* _version;
	TubaAPIInstanceUrls* _urls;
	GeeArrayList* _languages;
	TubaAPIMastodonConfigurations* _configuration;
	gint64 _max_toot_chars;
	TubaAPIMastodonConfigurationPolls* _poll_limits;
	gint64 _upload_limit;
	TubaAPIPleromaInstance* _pleroma;
	GeeArrayList* _rules;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tuba_limits;
	gboolean _tuba_can_translate;
	gint64 _tuba_max_alt_chars;
};

struct _TubaAPIInstanceRule {
	TubaEntity parent_instance;
	TubaAPIInstanceRulePrivate * priv;
};

struct _TubaAPIInstanceRuleClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceRulePrivate {
	gchar* _id;
	gchar* _text;
};

struct _TubaAPIInstanceUrls {
	TubaEntity parent_instance;
	TubaAPIInstanceUrlsPrivate * priv;
};

struct _TubaAPIInstanceUrlsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIInstanceUrlsPrivate {
	gchar* _streaming_api;
};

static gint TubaAPIInstance_private_offset;
static gpointer tuba_api_instance_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
static gint TubaAPIInstanceRule_private_offset;
static gpointer tuba_api_instance_rule_parent_class = NULL;
static gint TubaAPIInstanceUrls_private_offset;
static gpointer tuba_api_instance_urls_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_instance_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstance, g_object_unref)
VALA_EXTERN GType tuba_api_instance_urls_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceUrls, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configurations_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurations, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_polls_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationPolls, g_object_unref)
VALA_EXTERN GType tuba_api_pleroma_instance_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPleromaInstance, g_object_unref)
VALA_EXTERN GType tuba_api_instance_rule_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceRule, g_object_unref)
VALA_EXTERN GType tuba_api_instance_v2_configuration_accounts_char_limits_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2ConfigurationAccountsCharLimits, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_v2_configuration_accounts_char_limits_new (void);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_v2_configuration_accounts_char_limits_construct (GType object_type);
static GType tuba_api_instance_real_deserialize_array_type (TubaEntity* base,
                                                     const gchar* prop);
VALA_EXTERN TubaAPIInstance* tuba_api_instance_from (JsonNode* node,
                                         GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN TubaAPIInstance* tuba_api_instance_new (void);
VALA_EXTERN TubaAPIInstance* tuba_api_instance_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_instance_get_uri (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_uri (TubaAPIInstance* self,
                                const gchar* value);
VALA_EXTERN const gchar* tuba_api_instance_get_title (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_title (TubaAPIInstance* self,
                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_instance_get_thumbnail (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_thumbnail (TubaAPIInstance* self,
                                      const gchar* value);
VALA_EXTERN const gchar* tuba_api_instance_get_version (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_version (TubaAPIInstance* self,
                                    const gchar* value);
VALA_EXTERN TubaAPIInstanceUrls* tuba_api_instance_get_urls (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_urls (TubaAPIInstance* self,
                                 TubaAPIInstanceUrls* value);
VALA_EXTERN GeeArrayList* tuba_api_instance_get_languages (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_languages (TubaAPIInstance* self,
                                      GeeArrayList* value);
VALA_EXTERN TubaAPIMastodonConfigurations* tuba_api_instance_get_configuration (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_configuration (TubaAPIInstance* self,
                                          TubaAPIMastodonConfigurations* value);
VALA_EXTERN gint64 tuba_api_instance_get_max_toot_chars (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_max_toot_chars (TubaAPIInstance* self,
                                           gint64 value);
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_instance_get_poll_limits (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_poll_limits (TubaAPIInstance* self,
                                        TubaAPIMastodonConfigurationPolls* value);
VALA_EXTERN gint64 tuba_api_instance_get_upload_limit (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_upload_limit (TubaAPIInstance* self,
                                         gint64 value);
VALA_EXTERN TubaAPIPleromaInstance* tuba_api_instance_get_pleroma (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_pleroma (TubaAPIInstance* self,
                                    TubaAPIPleromaInstance* value);
VALA_EXTERN GeeArrayList* tuba_api_instance_get_rules (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_rules (TubaAPIInstance* self,
                                  GeeArrayList* value);
VALA_EXTERN TubaAPIInstanceV2ConfigurationAccountsCharLimits* tuba_api_instance_get_tuba_limits (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_tuba_limits (TubaAPIInstance* self,
                                        TubaAPIInstanceV2ConfigurationAccountsCharLimits* value);
VALA_EXTERN gboolean tuba_api_instance_get_tuba_can_translate (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_tuba_can_translate (TubaAPIInstance* self,
                                               gboolean value);
VALA_EXTERN gint64 tuba_api_instance_get_tuba_max_alt_chars (TubaAPIInstance* self);
VALA_EXTERN void tuba_api_instance_set_tuba_max_alt_chars (TubaAPIInstance* self,
                                               gint64 value);
VALA_EXTERN gboolean tuba_api_instance_get_supports_quote_posting (TubaAPIInstance* self);
VALA_EXTERN GType tuba_api_pleroma_instance_metadata_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPleromaInstanceMetadata, g_object_unref)
VALA_EXTERN TubaAPIPleromaInstanceMetadata* tuba_api_pleroma_instance_get_metadata (TubaAPIPleromaInstance* self);
VALA_EXTERN gchar** tuba_api_pleroma_instance_metadata_get_features (TubaAPIPleromaInstanceMetadata* self,
                                                         gint* result_length1);
static gboolean _vala_string_array_contains (gchar* * stack,
                                      gssize stack_length,
                                      const gchar* needle);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN GType tuba_api_instance_v2_api_versions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2APIVersions, g_object_unref)
VALA_EXTERN TubaAPIInstanceV2APIVersions* tuba_instance_account_get_tuba_api_versions (TubaInstanceAccount* self);
VALA_EXTERN gint8 tuba_api_instance_v2_api_versions_get_mastodon (TubaAPIInstanceV2APIVersions* self);
VALA_EXTERN gboolean tuba_api_instance_get_supports_bubble (TubaAPIInstance* self);
VALA_EXTERN gint8 tuba_api_instance_v2_api_versions_get_chuckya (TubaAPIInstanceV2APIVersions* self);
VALA_EXTERN gchar** tuba_api_instance_get_compat_supported_mime_types (TubaAPIInstance* self,
                                                           gint* result_length1);
VALA_EXTERN gchar** tuba_api_pleroma_instance_metadata_get_post_formats (TubaAPIPleromaInstanceMetadata* self,
                                                             gint* result_length1);
VALA_EXTERN GType tuba_api_mastodon_configuration_statuses_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationStatuses, g_object_unref)
VALA_EXTERN TubaAPIMastodonConfigurationStatuses* tuba_api_mastodon_configurations_get_statuses (TubaAPIMastodonConfigurations* self);
VALA_EXTERN gchar** tuba_api_mastodon_configuration_statuses_get_supported_mime_types (TubaAPIMastodonConfigurationStatuses* self,
                                                                           gint* result_length1);
VALA_EXTERN gint64 tuba_api_instance_get_compat_fields_limits_max_fields (TubaAPIInstance* self);
VALA_EXTERN GType tuba_api_pleroma_instance_metadata_field_limits_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPleromaInstanceMetadataFieldLimits, g_object_unref)
VALA_EXTERN TubaAPIPleromaInstanceMetadataFieldLimits* tuba_api_pleroma_instance_metadata_get_fields_limits (TubaAPIPleromaInstanceMetadata* self);
VALA_EXTERN gint64 tuba_api_pleroma_instance_metadata_field_limits_get_max_fields (TubaAPIPleromaInstanceMetadataFieldLimits* self);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_fields_limits_name_length (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_pleroma_instance_metadata_field_limits_get_name_length (TubaAPIPleromaInstanceMetadataFieldLimits* self);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_fields_limits_value_length (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_pleroma_instance_metadata_field_limits_get_value_length (TubaAPIPleromaInstanceMetadataFieldLimits* self);
VALA_EXTERN gint64 tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (TubaAPIInstanceV2ConfigurationAccountsCharLimits* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_max_media_attachments (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_statuses_get_max_media_attachments (TubaAPIMastodonConfigurationStatuses* self);
VALA_EXTERN gint tuba_api_instance_get_compat_status_characters_reserved_per_url (TubaAPIInstance* self);
VALA_EXTERN gint tuba_api_mastodon_configuration_statuses_get_characters_reserved_per_url (TubaAPIMastodonConfigurationStatuses* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_max_characters (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_statuses_get_max_characters (TubaAPIMastodonConfigurationStatuses* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_max_image_size (TubaAPIInstance* self);
VALA_EXTERN GType tuba_api_mastodon_configuration_media_attachments_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationMediaAttachments, g_object_unref)
VALA_EXTERN TubaAPIMastodonConfigurationMediaAttachments* tuba_api_mastodon_configurations_get_media_attachments (TubaAPIMastodonConfigurations* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_media_attachments_get_image_size_limit (TubaAPIMastodonConfigurationMediaAttachments* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_max_video_size (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_media_attachments_get_video_size_limit (TubaAPIMastodonConfigurationMediaAttachments* self);
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_instance_get_compat_status_polls (TubaAPIInstance* self);
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_mastodon_configurations_get_polls (TubaAPIMastodonConfigurations* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_poll_max_characters (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_compat_status_poll_max_characters (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_poll_max_options (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_options (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_poll_min_expiration (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_min_expiration (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_poll_max_expiration (TubaAPIInstance* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_expiration (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN gint64 tuba_api_instance_get_compat_status_reactions_max (TubaAPIInstance* self);
VALA_EXTERN GType tuba_api_mastodon_configuration_reactions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationReactions, g_object_unref)
VALA_EXTERN TubaAPIMastodonConfigurationReactions* tuba_api_mastodon_configurations_get_reactions (TubaAPIMastodonConfigurations* self);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_reactions_get_max_reactions (TubaAPIMastodonConfigurationReactions* self);
VALA_EXTERN TubaAPIInstanceRule* tuba_api_instance_rule_new (void);
VALA_EXTERN TubaAPIInstanceRule* tuba_api_instance_rule_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_instance_rule_get_id (TubaAPIInstanceRule* self);
VALA_EXTERN void tuba_api_instance_rule_set_id (TubaAPIInstanceRule* self,
                                    const gchar* value);
VALA_EXTERN const gchar* tuba_api_instance_rule_get_text (TubaAPIInstanceRule* self);
VALA_EXTERN void tuba_api_instance_rule_set_text (TubaAPIInstanceRule* self,
                                      const gchar* value);
static void tuba_api_instance_rule_finalize (GObject * obj);
static GType tuba_api_instance_rule_get_type_once (void);
static void _vala_tuba_api_instance_rule_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_tuba_api_instance_rule_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
VALA_EXTERN TubaAPIInstanceUrls* tuba_api_instance_urls_new (void);
VALA_EXTERN TubaAPIInstanceUrls* tuba_api_instance_urls_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_instance_urls_get_streaming_api (TubaAPIInstanceUrls* self);
VALA_EXTERN void tuba_api_instance_urls_set_streaming_api (TubaAPIInstanceUrls* self,
                                               const gchar* value);
static void tuba_api_instance_urls_finalize (GObject * obj);
static GType tuba_api_instance_urls_get_type_once (void);
static void _vala_tuba_api_instance_urls_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_tuba_api_instance_urls_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
static void tuba_api_instance_finalize (GObject * obj);
static GType tuba_api_instance_get_type_once (void);
static void _vala_tuba_api_instance_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_tuba_api_instance_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);

static inline gpointer
tuba_api_instance_get_instance_private (TubaAPIInstance* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstance_private_offset);
}

static GType
tuba_api_instance_real_deserialize_array_type (TubaEntity* base,
                                               const gchar* prop)
{
	TubaAPIInstance * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	GType result;
	self = (TubaAPIInstance*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("languages")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("rules")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_INSTANCE_TYPE_RULE;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_instance_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIInstance*
tuba_api_instance_from (JsonNode* node,
                        GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIInstance* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIInstance* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_INSTANCE, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_INSTANCE (_tmp0_) ? ((TubaAPIInstance*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPIInstance*
tuba_api_instance_construct (GType object_type)
{
	TubaAPIInstance * self = NULL;
	self = (TubaAPIInstance*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstance*
tuba_api_instance_new (void)
{
	return tuba_api_instance_construct (TUBA_API_TYPE_INSTANCE);
}

const gchar*
tuba_api_instance_get_uri (TubaAPIInstance* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_uri;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_uri (TubaAPIInstance* self,
                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_uri (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_uri);
		self->priv->_uri = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_URI_PROPERTY]);
	}
}

const gchar*
tuba_api_instance_get_title (TubaAPIInstance* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_title (TubaAPIInstance* self,
                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_title (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_title);
		self->priv->_title = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_TITLE_PROPERTY]);
	}
}

const gchar*
tuba_api_instance_get_thumbnail (TubaAPIInstance* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_thumbnail;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_thumbnail (TubaAPIInstance* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_thumbnail (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_thumbnail);
		self->priv->_thumbnail = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_THUMBNAIL_PROPERTY]);
	}
}

const gchar*
tuba_api_instance_get_version (TubaAPIInstance* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_version;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_version (TubaAPIInstance* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_version (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_version);
		self->priv->_version = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_VERSION_PROPERTY]);
	}
}

TubaAPIInstanceUrls*
tuba_api_instance_get_urls (TubaAPIInstance* self)
{
	TubaAPIInstanceUrls* result;
	TubaAPIInstanceUrls* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_urls;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_urls (TubaAPIInstance* self,
                            TubaAPIInstanceUrls* value)
{
	TubaAPIInstanceUrls* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_urls (self);
	if (old_value != value) {
		TubaAPIInstanceUrls* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_urls);
		self->priv->_urls = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_URLS_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_instance_get_languages (TubaAPIInstance* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_languages;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_languages (TubaAPIInstance* self,
                                 GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_languages (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_languages);
		self->priv->_languages = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_LANGUAGES_PROPERTY]);
	}
}

TubaAPIMastodonConfigurations*
tuba_api_instance_get_configuration (TubaAPIInstance* self)
{
	TubaAPIMastodonConfigurations* result;
	TubaAPIMastodonConfigurations* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_configuration;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_configuration (TubaAPIInstance* self,
                                     TubaAPIMastodonConfigurations* value)
{
	TubaAPIMastodonConfigurations* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_configuration (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurations* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_configuration);
		self->priv->_configuration = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_CONFIGURATION_PROPERTY]);
	}
}

gint64
tuba_api_instance_get_max_toot_chars (TubaAPIInstance* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_toot_chars;
	return result;
}

void
tuba_api_instance_set_max_toot_chars (TubaAPIInstance* self,
                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_max_toot_chars (self);
	if (old_value != value) {
		self->priv->_max_toot_chars = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY]);
	}
}

TubaAPIMastodonConfigurationPolls*
tuba_api_instance_get_poll_limits (TubaAPIInstance* self)
{
	TubaAPIMastodonConfigurationPolls* result;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_poll_limits;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_poll_limits (TubaAPIInstance* self,
                                   TubaAPIMastodonConfigurationPolls* value)
{
	TubaAPIMastodonConfigurationPolls* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_poll_limits (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurationPolls* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_poll_limits);
		self->priv->_poll_limits = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY]);
	}
}

gint64
tuba_api_instance_get_upload_limit (TubaAPIInstance* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_upload_limit;
	return result;
}

void
tuba_api_instance_set_upload_limit (TubaAPIInstance* self,
                                    gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_upload_limit (self);
	if (old_value != value) {
		self->priv->_upload_limit = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY]);
	}
}

TubaAPIPleromaInstance*
tuba_api_instance_get_pleroma (TubaAPIInstance* self)
{
	TubaAPIPleromaInstance* result;
	TubaAPIPleromaInstance* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_pleroma;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_pleroma (TubaAPIInstance* self,
                               TubaAPIPleromaInstance* value)
{
	TubaAPIPleromaInstance* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_pleroma (self);
	if (old_value != value) {
		TubaAPIPleromaInstance* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_pleroma);
		self->priv->_pleroma = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_PLEROMA_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_instance_get_rules (TubaAPIInstance* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_rules;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_rules (TubaAPIInstance* self,
                             GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_rules (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_rules);
		self->priv->_rules = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_RULES_PROPERTY]);
	}
}

TubaAPIInstanceV2ConfigurationAccountsCharLimits*
tuba_api_instance_get_tuba_limits (TubaAPIInstance* self)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* result;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tuba_limits;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_set_tuba_limits (TubaAPIInstance* self,
                                   TubaAPIInstanceV2ConfigurationAccountsCharLimits* value)
{
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_tuba_limits (self);
	if (old_value != value) {
		TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_tuba_limits);
		self->priv->_tuba_limits = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY]);
	}
}

gboolean
tuba_api_instance_get_tuba_can_translate (TubaAPIInstance* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_tuba_can_translate;
	return result;
}

void
tuba_api_instance_set_tuba_can_translate (TubaAPIInstance* self,
                                          gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_tuba_can_translate (self);
	if (old_value != value) {
		self->priv->_tuba_can_translate = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY]);
	}
}

gint64
tuba_api_instance_get_tuba_max_alt_chars (TubaAPIInstance* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_tuba_max_alt_chars;
	return result;
}

void
tuba_api_instance_set_tuba_max_alt_chars (TubaAPIInstance* self,
                                          gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_get_tuba_max_alt_chars (self);
	if (old_value != value) {
		self->priv->_tuba_max_alt_chars = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY]);
	}
}

static gboolean
_vala_string_array_contains (gchar* * stack,
                             gssize stack_length,
                             const gchar* needle)
{
	gssize i;
	for (i = 0; i < stack_length; i++) {
		if (g_strcmp0 (stack[i], needle) == 0) {
			return TRUE;
		}
	}
	return FALSE;
}

gboolean
tuba_api_instance_get_supports_quote_posting (TubaAPIInstance* self)
{
	gboolean result;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	TubaAPIPleromaInstance* _tmp2_;
	TubaAccountStore* _tmp18_;
	TubaInstanceAccount* _tmp19_;
	TubaInstanceAccount* _tmp20_;
	TubaAPIInstanceV2APIVersions* _tmp21_;
	TubaAPIInstanceV2APIVersions* _tmp22_;
	gint8 _tmp23_;
	gint8 _tmp24_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp2_ = self->priv->_pleroma;
	if (_tmp2_ != NULL) {
		TubaAPIPleromaInstance* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		TubaAPIPleromaInstanceMetadata* _tmp5_;
		_tmp3_ = self->priv->_pleroma;
		_tmp4_ = tuba_api_pleroma_instance_get_metadata (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ != NULL;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaAPIPleromaInstance* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		TubaAPIPleromaInstanceMetadata* _tmp8_;
		gchar** _tmp9_;
		gint _tmp9__length1;
		gint _tmp10_ = 0;
		gchar** _tmp11_;
		gint _tmp11__length1;
		_tmp6_ = self->priv->_pleroma;
		_tmp7_ = tuba_api_pleroma_instance_get_metadata (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_pleroma_instance_metadata_get_features (_tmp8_, &_tmp10_);
		_tmp9__length1 = _tmp10_;
		_tmp11_ = _tmp9_;
		_tmp11__length1 = _tmp9__length1;
		_tmp0_ = _tmp11_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp12_;
		TubaAPIPleromaInstanceMetadata* _tmp13_;
		TubaAPIPleromaInstanceMetadata* _tmp14_;
		gchar** _tmp15_;
		gint _tmp15__length1;
		gint _tmp16_ = 0;
		gchar** _tmp17_;
		gint _tmp17__length1;
		_tmp12_ = self->priv->_pleroma;
		_tmp13_ = tuba_api_pleroma_instance_get_metadata (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = tuba_api_pleroma_instance_metadata_get_features (_tmp14_, &_tmp16_);
		_tmp15__length1 = _tmp16_;
		_tmp17_ = _tmp15_;
		_tmp17__length1 = _tmp15__length1;
		result = _vala_string_array_contains (_tmp17_, _tmp17__length1, "quote_posting");
		return result;
	}
	_tmp18_ = tuba_accounts;
	_tmp19_ = tuba_account_store_get_active (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = tuba_instance_account_get_tuba_api_versions (_tmp20_);
	_tmp22_ = _tmp21_;
	_tmp23_ = tuba_api_instance_v2_api_versions_get_mastodon (_tmp22_);
	_tmp24_ = _tmp23_;
	result = ((gint) _tmp24_) >= 7;
	return result;
}

gboolean
tuba_api_instance_get_supports_bubble (TubaAPIInstance* self)
{
	gboolean result;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	TubaAPIPleromaInstance* _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp2_ = self->priv->_pleroma;
	if (_tmp2_ != NULL) {
		TubaAPIPleromaInstance* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		TubaAPIPleromaInstanceMetadata* _tmp5_;
		_tmp3_ = self->priv->_pleroma;
		_tmp4_ = tuba_api_pleroma_instance_get_metadata (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ != NULL;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaAPIPleromaInstance* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		TubaAPIPleromaInstanceMetadata* _tmp8_;
		gchar** _tmp9_;
		gint _tmp9__length1;
		gint _tmp10_ = 0;
		gchar** _tmp11_;
		gint _tmp11__length1;
		_tmp6_ = self->priv->_pleroma;
		_tmp7_ = tuba_api_pleroma_instance_get_metadata (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_pleroma_instance_metadata_get_features (_tmp8_, &_tmp10_);
		_tmp9__length1 = _tmp10_;
		_tmp11_ = _tmp9_;
		_tmp11__length1 = _tmp9__length1;
		_tmp0_ = _tmp11_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp12_;
		TubaAPIPleromaInstanceMetadata* _tmp13_;
		TubaAPIPleromaInstanceMetadata* _tmp14_;
		gchar** _tmp15_;
		gint _tmp15__length1;
		gint _tmp16_ = 0;
		gchar** _tmp17_;
		gint _tmp17__length1;
		_tmp12_ = self->priv->_pleroma;
		_tmp13_ = tuba_api_pleroma_instance_get_metadata (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = tuba_api_pleroma_instance_metadata_get_features (_tmp14_, &_tmp16_);
		_tmp15__length1 = _tmp16_;
		_tmp17_ = _tmp15_;
		_tmp17__length1 = _tmp15__length1;
		result = _vala_string_array_contains (_tmp17_, _tmp17__length1, "bubble_timeline");
		return result;
	} else {
		TubaAccountStore* _tmp18_;
		TubaInstanceAccount* _tmp19_;
		TubaInstanceAccount* _tmp20_;
		TubaAPIInstanceV2APIVersions* _tmp21_;
		TubaAPIInstanceV2APIVersions* _tmp22_;
		gint8 _tmp23_;
		gint8 _tmp24_;
		_tmp18_ = tuba_accounts;
		_tmp19_ = tuba_account_store_get_active (_tmp18_);
		_tmp20_ = _tmp19_;
		_tmp21_ = tuba_instance_account_get_tuba_api_versions (_tmp20_);
		_tmp22_ = _tmp21_;
		_tmp23_ = tuba_api_instance_v2_api_versions_get_chuckya (_tmp22_);
		_tmp24_ = _tmp23_;
		if (((gint) _tmp24_) > 0) {
			result = TRUE;
			return result;
		}
	}
	result = FALSE;
	return result;
}

gchar**
tuba_api_instance_get_compat_supported_mime_types (TubaAPIInstance* self,
                                                   gint* result_length1)
{
	gchar** result;
	gboolean _tmp0_ = FALSE;
	TubaAPIPleromaInstance* _tmp1_;
	TubaAPIMastodonConfigurations* _tmp18_;
	TubaAPIMastodonConfigurationStatuses* _tmp19_;
	TubaAPIMastodonConfigurationStatuses* _tmp20_;
	gchar** _tmp21_;
	gint _tmp21__length1;
	gint _tmp22_ = 0;
	gchar** _tmp23_;
	gint _tmp23__length1;
	gchar** _tmp24_;
	gint _tmp24__length1;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp1_ = self->priv->_pleroma;
	if (_tmp1_ != NULL) {
		TubaAPIPleromaInstance* _tmp2_;
		TubaAPIPleromaInstanceMetadata* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		_tmp2_ = self->priv->_pleroma;
		_tmp3_ = tuba_api_pleroma_instance_get_metadata (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp5_;
		TubaAPIPleromaInstanceMetadata* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		gchar** _tmp8_;
		gint _tmp8__length1;
		gint _tmp9_ = 0;
		gchar** _tmp10_;
		gint _tmp10__length1;
		gchar** _tmp11_;
		gint _tmp11__length1;
		_tmp5_ = self->priv->_pleroma;
		_tmp6_ = tuba_api_pleroma_instance_get_metadata (_tmp5_);
		_tmp7_ = _tmp6_;
		_tmp8_ = tuba_api_pleroma_instance_metadata_get_post_formats (_tmp7_, &_tmp9_);
		_tmp8__length1 = _tmp9_;
		_tmp10_ = _tmp8_;
		_tmp10__length1 = _tmp8__length1;
		_tmp11_ = _tmp10_;
		_tmp11__length1 = _tmp10__length1;
		if (result_length1) {
			*result_length1 = _tmp11__length1;
		}
		result = _tmp11_;
		return result;
	} else {
		gboolean _tmp12_ = FALSE;
		TubaAPIMastodonConfigurations* _tmp13_;
		_tmp13_ = self->priv->_configuration;
		if (_tmp13_ == NULL) {
			_tmp12_ = TRUE;
		} else {
			TubaAPIMastodonConfigurations* _tmp14_;
			TubaAPIMastodonConfigurationStatuses* _tmp15_;
			TubaAPIMastodonConfigurationStatuses* _tmp16_;
			_tmp14_ = self->priv->_configuration;
			_tmp15_ = tuba_api_mastodon_configurations_get_statuses (_tmp14_);
			_tmp16_ = _tmp15_;
			_tmp12_ = _tmp16_ == NULL;
		}
		if (_tmp12_) {
			gchar** _tmp17_;
			gint _tmp17__length1;
			_tmp17_ = NULL;
			_tmp17__length1 = 0;
			if (result_length1) {
				*result_length1 = _tmp17__length1;
			}
			result = _tmp17_;
			return result;
		}
	}
	_tmp18_ = self->priv->_configuration;
	_tmp19_ = tuba_api_mastodon_configurations_get_statuses (_tmp18_);
	_tmp20_ = _tmp19_;
	_tmp21_ = tuba_api_mastodon_configuration_statuses_get_supported_mime_types (_tmp20_, &_tmp22_);
	_tmp21__length1 = _tmp22_;
	_tmp23_ = _tmp21_;
	_tmp23__length1 = _tmp21__length1;
	_tmp24_ = _tmp23_;
	_tmp24__length1 = _tmp23__length1;
	if (result_length1) {
		*result_length1 = _tmp24__length1;
	}
	result = _tmp24_;
	return result;
}

gint64
tuba_api_instance_get_compat_fields_limits_max_fields (TubaAPIInstance* self)
{
	gint64 result;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	TubaAPIPleromaInstance* _tmp2_;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp18_;
	gint64 _tmp19_;
	gint64 _tmp20_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp2_ = self->priv->_pleroma;
	if (_tmp2_ != NULL) {
		TubaAPIPleromaInstance* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		TubaAPIPleromaInstanceMetadata* _tmp5_;
		_tmp3_ = self->priv->_pleroma;
		_tmp4_ = tuba_api_pleroma_instance_get_metadata (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ != NULL;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaAPIPleromaInstance* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		TubaAPIPleromaInstanceMetadata* _tmp8_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp9_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp10_;
		_tmp6_ = self->priv->_pleroma;
		_tmp7_ = tuba_api_pleroma_instance_get_metadata (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp8_);
		_tmp10_ = _tmp9_;
		_tmp0_ = _tmp10_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp11_;
		TubaAPIPleromaInstanceMetadata* _tmp12_;
		TubaAPIPleromaInstanceMetadata* _tmp13_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp14_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp15_;
		gint64 _tmp16_;
		gint64 _tmp17_;
		_tmp11_ = self->priv->_pleroma;
		_tmp12_ = tuba_api_pleroma_instance_get_metadata (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = tuba_api_pleroma_instance_metadata_field_limits_get_max_fields (_tmp15_);
		_tmp17_ = _tmp16_;
		result = _tmp17_;
		return result;
	}
	_tmp18_ = self->priv->_tuba_limits;
	_tmp19_ = tuba_api_instance_v2_configuration_accounts_char_limits_get_max_profile_fields (_tmp18_);
	_tmp20_ = _tmp19_;
	result = _tmp20_;
	return result;
}

gint64
tuba_api_instance_get_compat_fields_limits_name_length (TubaAPIInstance* self)
{
	gint64 result;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	TubaAPIPleromaInstance* _tmp2_;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp18_;
	gint64 _tmp19_;
	gint64 _tmp20_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp2_ = self->priv->_pleroma;
	if (_tmp2_ != NULL) {
		TubaAPIPleromaInstance* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		TubaAPIPleromaInstanceMetadata* _tmp5_;
		_tmp3_ = self->priv->_pleroma;
		_tmp4_ = tuba_api_pleroma_instance_get_metadata (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ != NULL;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaAPIPleromaInstance* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		TubaAPIPleromaInstanceMetadata* _tmp8_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp9_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp10_;
		_tmp6_ = self->priv->_pleroma;
		_tmp7_ = tuba_api_pleroma_instance_get_metadata (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp8_);
		_tmp10_ = _tmp9_;
		_tmp0_ = _tmp10_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp11_;
		TubaAPIPleromaInstanceMetadata* _tmp12_;
		TubaAPIPleromaInstanceMetadata* _tmp13_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp14_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp15_;
		gint64 _tmp16_;
		gint64 _tmp17_;
		_tmp11_ = self->priv->_pleroma;
		_tmp12_ = tuba_api_pleroma_instance_get_metadata (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = tuba_api_pleroma_instance_metadata_field_limits_get_name_length (_tmp15_);
		_tmp17_ = _tmp16_;
		result = _tmp17_;
		return result;
	}
	_tmp18_ = self->priv->_tuba_limits;
	_tmp19_ = tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_name_limit (_tmp18_);
	_tmp20_ = _tmp19_;
	result = _tmp20_;
	return result;
}

gint64
tuba_api_instance_get_compat_fields_limits_value_length (TubaAPIInstance* self)
{
	gint64 result;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	TubaAPIPleromaInstance* _tmp2_;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp18_;
	gint64 _tmp19_;
	gint64 _tmp20_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp2_ = self->priv->_pleroma;
	if (_tmp2_ != NULL) {
		TubaAPIPleromaInstance* _tmp3_;
		TubaAPIPleromaInstanceMetadata* _tmp4_;
		TubaAPIPleromaInstanceMetadata* _tmp5_;
		_tmp3_ = self->priv->_pleroma;
		_tmp4_ = tuba_api_pleroma_instance_get_metadata (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp1_ = _tmp5_ != NULL;
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaAPIPleromaInstance* _tmp6_;
		TubaAPIPleromaInstanceMetadata* _tmp7_;
		TubaAPIPleromaInstanceMetadata* _tmp8_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp9_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp10_;
		_tmp6_ = self->priv->_pleroma;
		_tmp7_ = tuba_api_pleroma_instance_get_metadata (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp8_);
		_tmp10_ = _tmp9_;
		_tmp0_ = _tmp10_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIPleromaInstance* _tmp11_;
		TubaAPIPleromaInstanceMetadata* _tmp12_;
		TubaAPIPleromaInstanceMetadata* _tmp13_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp14_;
		TubaAPIPleromaInstanceMetadataFieldLimits* _tmp15_;
		gint64 _tmp16_;
		gint64 _tmp17_;
		_tmp11_ = self->priv->_pleroma;
		_tmp12_ = tuba_api_pleroma_instance_get_metadata (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = tuba_api_pleroma_instance_metadata_get_fields_limits (_tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = tuba_api_pleroma_instance_metadata_field_limits_get_value_length (_tmp15_);
		_tmp17_ = _tmp16_;
		result = _tmp17_;
		return result;
	}
	_tmp18_ = self->priv->_tuba_limits;
	_tmp19_ = tuba_api_instance_v2_configuration_accounts_char_limits_get_profile_field_value_limit (_tmp18_);
	_tmp20_ = _tmp19_;
	result = _tmp20_;
	return result;
}

gint64
tuba_api_instance_get_compat_status_max_media_attachments (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurations* _tmp0_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationStatuses* _tmp2_;
		TubaAPIMastodonConfigurationStatuses* _tmp3_;
		gint64 _tmp4_;
		gint64 _tmp5_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_statuses (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_mastodon_configuration_statuses_get_max_media_attachments (_tmp3_);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	result = (gint64) 4;
	return result;
}

gint
tuba_api_instance_get_compat_status_characters_reserved_per_url (TubaAPIInstance* self)
{
	gint result;
	TubaAPIMastodonConfigurations* _tmp0_;
	g_return_val_if_fail (self != NULL, -1);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationStatuses* _tmp2_;
		TubaAPIMastodonConfigurationStatuses* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_statuses (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_mastodon_configuration_statuses_get_characters_reserved_per_url (_tmp3_);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	result = 0;
	return result;
}

gint64
tuba_api_instance_get_compat_status_max_characters (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurations* _tmp0_;
	gint64 _tmp6_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationStatuses* _tmp2_;
		TubaAPIMastodonConfigurationStatuses* _tmp3_;
		gint64 _tmp4_;
		gint64 _tmp5_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_statuses (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_mastodon_configuration_statuses_get_max_characters (_tmp3_);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	_tmp6_ = self->priv->_max_toot_chars;
	result = _tmp6_;
	return result;
}

gint64
tuba_api_instance_get_compat_status_max_image_size (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurations* _tmp0_;
	gint64 _tmp6_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationMediaAttachments* _tmp2_;
		TubaAPIMastodonConfigurationMediaAttachments* _tmp3_;
		gint64 _tmp4_;
		gint64 _tmp5_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_media_attachments (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_mastodon_configuration_media_attachments_get_image_size_limit (_tmp3_);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	_tmp6_ = self->priv->_upload_limit;
	result = _tmp6_;
	return result;
}

gint64
tuba_api_instance_get_compat_status_max_video_size (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurations* _tmp0_;
	gint64 _tmp6_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationMediaAttachments* _tmp2_;
		TubaAPIMastodonConfigurationMediaAttachments* _tmp3_;
		gint64 _tmp4_;
		gint64 _tmp5_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_media_attachments (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_mastodon_configuration_media_attachments_get_video_size_limit (_tmp3_);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		return result;
	}
	_tmp6_ = self->priv->_upload_limit;
	result = _tmp6_;
	return result;
}

TubaAPIMastodonConfigurationPolls*
tuba_api_instance_get_compat_status_polls (TubaAPIInstance* self)
{
	TubaAPIMastodonConfigurationPolls* result;
	TubaAPIMastodonConfigurations* _tmp0_;
	TubaAPIMastodonConfigurationPolls* _tmp4_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_configuration;
	if (_tmp0_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp1_;
		TubaAPIMastodonConfigurationPolls* _tmp2_;
		TubaAPIMastodonConfigurationPolls* _tmp3_;
		_tmp1_ = self->priv->_configuration;
		_tmp2_ = tuba_api_mastodon_configurations_get_polls (_tmp1_);
		_tmp3_ = _tmp2_;
		result = _tmp3_;
		return result;
	}
	_tmp4_ = self->priv->_poll_limits;
	result = _tmp4_;
	return result;
}

gint64
tuba_api_instance_get_compat_status_poll_max_characters (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurationPolls* compat_polls = NULL;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	TubaAPIMastodonConfigurationPolls* _tmp1_;
	TubaAPIMastodonConfigurationPolls* _tmp2_;
	TubaAPIMastodonConfigurationPolls* _tmp3_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = tuba_api_instance_get_compat_status_polls (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	compat_polls = _tmp2_;
	_tmp3_ = compat_polls;
	if (_tmp3_ != NULL) {
		TubaAPIMastodonConfigurationPolls* _tmp4_;
		gint64 _tmp5_;
		gint64 _tmp6_;
		_tmp4_ = compat_polls;
		_tmp5_ = tuba_api_mastodon_configuration_polls_get_compat_status_poll_max_characters (_tmp4_);
		_tmp6_ = _tmp5_;
		result = _tmp6_;
		_g_object_unref0 (compat_polls);
		return result;
	}
	result = (gint64) 50;
	_g_object_unref0 (compat_polls);
	return result;
}

gint64
tuba_api_instance_get_compat_status_poll_max_options (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurationPolls* compat_polls = NULL;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	TubaAPIMastodonConfigurationPolls* _tmp1_;
	TubaAPIMastodonConfigurationPolls* _tmp2_;
	TubaAPIMastodonConfigurationPolls* _tmp3_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = tuba_api_instance_get_compat_status_polls (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	compat_polls = _tmp2_;
	_tmp3_ = compat_polls;
	if (_tmp3_ != NULL) {
		TubaAPIMastodonConfigurationPolls* _tmp4_;
		gint64 _tmp5_;
		gint64 _tmp6_;
		_tmp4_ = compat_polls;
		_tmp5_ = tuba_api_mastodon_configuration_polls_get_max_options (_tmp4_);
		_tmp6_ = _tmp5_;
		result = _tmp6_;
		_g_object_unref0 (compat_polls);
		return result;
	}
	result = (gint64) 4;
	_g_object_unref0 (compat_polls);
	return result;
}

gint64
tuba_api_instance_get_compat_status_poll_min_expiration (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurationPolls* compat_polls = NULL;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	TubaAPIMastodonConfigurationPolls* _tmp1_;
	TubaAPIMastodonConfigurationPolls* _tmp2_;
	TubaAPIMastodonConfigurationPolls* _tmp3_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = tuba_api_instance_get_compat_status_polls (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	compat_polls = _tmp2_;
	_tmp3_ = compat_polls;
	if (_tmp3_ != NULL) {
		TubaAPIMastodonConfigurationPolls* _tmp4_;
		gint64 _tmp5_;
		gint64 _tmp6_;
		_tmp4_ = compat_polls;
		_tmp5_ = tuba_api_mastodon_configuration_polls_get_min_expiration (_tmp4_);
		_tmp6_ = _tmp5_;
		result = _tmp6_;
		_g_object_unref0 (compat_polls);
		return result;
	}
	result = (gint64) 300;
	_g_object_unref0 (compat_polls);
	return result;
}

gint64
tuba_api_instance_get_compat_status_poll_max_expiration (TubaAPIInstance* self)
{
	gint64 result;
	TubaAPIMastodonConfigurationPolls* compat_polls = NULL;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	TubaAPIMastodonConfigurationPolls* _tmp1_;
	TubaAPIMastodonConfigurationPolls* _tmp2_;
	TubaAPIMastodonConfigurationPolls* _tmp3_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp0_ = tuba_api_instance_get_compat_status_polls (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	compat_polls = _tmp2_;
	_tmp3_ = compat_polls;
	if (_tmp3_ != NULL) {
		TubaAPIMastodonConfigurationPolls* _tmp4_;
		gint64 _tmp5_;
		gint64 _tmp6_;
		_tmp4_ = compat_polls;
		_tmp5_ = tuba_api_mastodon_configuration_polls_get_max_expiration (_tmp4_);
		_tmp6_ = _tmp5_;
		result = _tmp6_;
		_g_object_unref0 (compat_polls);
		return result;
	}
	result = (gint64) 2629746;
	_g_object_unref0 (compat_polls);
	return result;
}

gint64
tuba_api_instance_get_compat_status_reactions_max (TubaAPIInstance* self)
{
	gint64 result;
	gboolean _tmp0_ = FALSE;
	TubaAPIMastodonConfigurations* _tmp1_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp1_ = self->priv->_configuration;
	if (_tmp1_ != NULL) {
		TubaAPIMastodonConfigurations* _tmp2_;
		TubaAPIMastodonConfigurationReactions* _tmp3_;
		TubaAPIMastodonConfigurationReactions* _tmp4_;
		_tmp2_ = self->priv->_configuration;
		_tmp3_ = tuba_api_mastodon_configurations_get_reactions (_tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ != NULL;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaAPIMastodonConfigurations* _tmp5_;
		TubaAPIMastodonConfigurationReactions* _tmp6_;
		TubaAPIMastodonConfigurationReactions* _tmp7_;
		gint64 _tmp8_;
		gint64 _tmp9_;
		_tmp5_ = self->priv->_configuration;
		_tmp6_ = tuba_api_mastodon_configurations_get_reactions (_tmp5_);
		_tmp7_ = _tmp6_;
		_tmp8_ = tuba_api_mastodon_configuration_reactions_get_max_reactions (_tmp7_);
		_tmp9_ = _tmp8_;
		result = _tmp9_;
		return result;
	}
	result = (gint64) 0;
	return result;
}

static inline gpointer
tuba_api_instance_rule_get_instance_private (TubaAPIInstanceRule* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceRule_private_offset);
}

TubaAPIInstanceRule*
tuba_api_instance_rule_construct (GType object_type)
{
	TubaAPIInstanceRule * self = NULL;
	self = (TubaAPIInstanceRule*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceRule*
tuba_api_instance_rule_new (void)
{
	return tuba_api_instance_rule_construct (TUBA_API_INSTANCE_TYPE_RULE);
}

const gchar*
tuba_api_instance_rule_get_id (TubaAPIInstanceRule* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_rule_set_id (TubaAPIInstanceRule* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_rule_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_rule_properties[TUBA_API_INSTANCE_RULE_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_instance_rule_get_text (TubaAPIInstanceRule* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_rule_set_text (TubaAPIInstanceRule* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_rule_get_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_text);
		self->priv->_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_rule_properties[TUBA_API_INSTANCE_RULE_TEXT_PROPERTY]);
	}
}

static void
tuba_api_instance_rule_class_init (TubaAPIInstanceRuleClass * klass,
                                   gpointer klass_data)
{
	tuba_api_instance_rule_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceRule_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_rule_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_rule_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_rule_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_RULE_ID_PROPERTY, tuba_api_instance_rule_properties[TUBA_API_INSTANCE_RULE_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_RULE_TEXT_PROPERTY, tuba_api_instance_rule_properties[TUBA_API_INSTANCE_RULE_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_rule_instance_init (TubaAPIInstanceRule * self,
                                      gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	self->priv = tuba_api_instance_rule_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_id = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_text = _tmp1_;
}

static void
tuba_api_instance_rule_finalize (GObject * obj)
{
	TubaAPIInstanceRule * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRule);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_text);
	G_OBJECT_CLASS (tuba_api_instance_rule_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_rule_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceRuleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_rule_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceRule), 0, (GInstanceInitFunc) tuba_api_instance_rule_instance_init, NULL };
	GType tuba_api_instance_rule_type_id;
	tuba_api_instance_rule_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceRule", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceRule_private_offset = g_type_add_instance_private (tuba_api_instance_rule_type_id, sizeof (TubaAPIInstanceRulePrivate));
	return tuba_api_instance_rule_type_id;
}

GType
tuba_api_instance_rule_get_type (void)
{
	static GType tuba_api_instance_rule_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_rule_type_id__once)) {
		GType tuba_api_instance_rule_type_id;
		tuba_api_instance_rule_type_id = tuba_api_instance_rule_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_rule_type_id__once, tuba_api_instance_rule_type_id);
	}
	return tuba_api_instance_rule_type_id__once;
}

static void
_vala_tuba_api_instance_rule_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIInstanceRule * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRule);
	switch (property_id) {
		case TUBA_API_INSTANCE_RULE_ID_PROPERTY:
		g_value_set_string (value, tuba_api_instance_rule_get_id (self));
		break;
		case TUBA_API_INSTANCE_RULE_TEXT_PROPERTY:
		g_value_set_string (value, tuba_api_instance_rule_get_text (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_rule_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIInstanceRule * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_TYPE_RULE, TubaAPIInstanceRule);
	switch (property_id) {
		case TUBA_API_INSTANCE_RULE_ID_PROPERTY:
		tuba_api_instance_rule_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_INSTANCE_RULE_TEXT_PROPERTY:
		tuba_api_instance_rule_set_text (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_instance_urls_get_instance_private (TubaAPIInstanceUrls* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIInstanceUrls_private_offset);
}

TubaAPIInstanceUrls*
tuba_api_instance_urls_construct (GType object_type)
{
	TubaAPIInstanceUrls * self = NULL;
	self = (TubaAPIInstanceUrls*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIInstanceUrls*
tuba_api_instance_urls_new (void)
{
	return tuba_api_instance_urls_construct (TUBA_API_INSTANCE_TYPE_URLS);
}

const gchar*
tuba_api_instance_urls_get_streaming_api (TubaAPIInstanceUrls* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_streaming_api;
	result = _tmp0_;
	return result;
}

void
tuba_api_instance_urls_set_streaming_api (TubaAPIInstanceUrls* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_instance_urls_get_streaming_api (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_streaming_api);
		self->priv->_streaming_api = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_instance_urls_properties[TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY]);
	}
}

static void
tuba_api_instance_urls_class_init (TubaAPIInstanceUrlsClass * klass,
                                   gpointer klass_data)
{
	tuba_api_instance_urls_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstanceUrls_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_urls_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_urls_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_urls_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY, tuba_api_instance_urls_properties[TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY] = g_param_spec_string ("streaming-api", "streaming-api", "streaming-api", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_instance_urls_instance_init (TubaAPIInstanceUrls * self,
                                      gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_api_instance_urls_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_streaming_api = _tmp0_;
}

static void
tuba_api_instance_urls_finalize (GObject * obj)
{
	TubaAPIInstanceUrls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrls);
	_g_free0 (self->priv->_streaming_api);
	G_OBJECT_CLASS (tuba_api_instance_urls_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_urls_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceUrlsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_urls_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstanceUrls), 0, (GInstanceInitFunc) tuba_api_instance_urls_instance_init, NULL };
	GType tuba_api_instance_urls_type_id;
	tuba_api_instance_urls_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstanceUrls", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstanceUrls_private_offset = g_type_add_instance_private (tuba_api_instance_urls_type_id, sizeof (TubaAPIInstanceUrlsPrivate));
	return tuba_api_instance_urls_type_id;
}

GType
tuba_api_instance_urls_get_type (void)
{
	static GType tuba_api_instance_urls_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_urls_type_id__once)) {
		GType tuba_api_instance_urls_type_id;
		tuba_api_instance_urls_type_id = tuba_api_instance_urls_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_urls_type_id__once, tuba_api_instance_urls_type_id);
	}
	return tuba_api_instance_urls_type_id__once;
}

static void
_vala_tuba_api_instance_urls_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIInstanceUrls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrls);
	switch (property_id) {
		case TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY:
		g_value_set_string (value, tuba_api_instance_urls_get_streaming_api (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_urls_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIInstanceUrls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_INSTANCE_TYPE_URLS, TubaAPIInstanceUrls);
	switch (property_id) {
		case TUBA_API_INSTANCE_URLS_STREAMING_API_PROPERTY:
		tuba_api_instance_urls_set_streaming_api (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_instance_class_init (TubaAPIInstanceClass * klass,
                              gpointer klass_data)
{
	tuba_api_instance_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIInstance_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_instance_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_instance_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_instance_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_instance_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_URI_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_URI_PROPERTY] = g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_TITLE_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_THUMBNAIL_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_THUMBNAIL_PROPERTY] = g_param_spec_string ("thumbnail", "thumbnail", "thumbnail", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_VERSION_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_VERSION_PROPERTY] = g_param_spec_string ("version", "version", "version", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_URLS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_URLS_PROPERTY] = g_param_spec_object ("urls", "urls", "urls", TUBA_API_INSTANCE_TYPE_URLS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_LANGUAGES_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_LANGUAGES_PROPERTY] = g_param_spec_object ("languages", "languages", "languages", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_CONFIGURATION_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_CONFIGURATION_PROPERTY] = g_param_spec_object ("configuration", "configuration", "configuration", TUBA_API_MASTODON_TYPE_CONFIGURATIONS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY] = g_param_spec_int64 ("max-toot-chars", "max-toot-chars", "max-toot-chars", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY] = g_param_spec_object ("poll-limits", "poll-limits", "poll-limits", TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY] = g_param_spec_int64 ("upload-limit", "upload-limit", "upload-limit", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_PLEROMA_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_PLEROMA_PROPERTY] = g_param_spec_object ("pleroma", "pleroma", "pleroma", TUBA_API_PLEROMA_TYPE_INSTANCE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_RULES_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_RULES_PROPERTY] = g_param_spec_object ("rules", "rules", "rules", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY] = g_param_spec_object ("tuba-limits", "tuba-limits", "tuba-limits", TUBA_API_INSTANCE_V2_CONFIGURATION_TYPE_ACCOUNTS_CHAR_LIMITS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY] = g_param_spec_boolean ("tuba-can-translate", "tuba-can-translate", "tuba-can-translate", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY] = g_param_spec_int64 ("tuba-max-alt-chars", "tuba-max-alt-chars", "tuba-max-alt-chars", G_MININT64, G_MAXINT64, (gint64) 1500, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_SUPPORTS_QUOTE_POSTING_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_SUPPORTS_QUOTE_POSTING_PROPERTY] = g_param_spec_boolean ("supports-quote-posting", "supports-quote-posting", "supports-quote-posting", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_SUPPORTS_BUBBLE_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_SUPPORTS_BUBBLE_PROPERTY] = g_param_spec_boolean ("supports-bubble", "supports-bubble", "supports-bubble", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_SUPPORTED_MIME_TYPES_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_SUPPORTED_MIME_TYPES_PROPERTY] = g_param_spec_boxed ("compat-supported-mime-types", "compat-supported-mime-types", "compat-supported-mime-types", G_TYPE_STRV, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_MAX_FIELDS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_MAX_FIELDS_PROPERTY] = g_param_spec_int64 ("compat-fields-limits-max-fields", "compat-fields-limits-max-fields", "compat-fields-limits-max-fields", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_NAME_LENGTH_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_NAME_LENGTH_PROPERTY] = g_param_spec_int64 ("compat-fields-limits-name-length", "compat-fields-limits-name-length", "compat-fields-limits-name-length", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_VALUE_LENGTH_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_VALUE_LENGTH_PROPERTY] = g_param_spec_int64 ("compat-fields-limits-value-length", "compat-fields-limits-value-length", "compat-fields-limits-value-length", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_MAX_MEDIA_ATTACHMENTS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_MAX_MEDIA_ATTACHMENTS_PROPERTY] = g_param_spec_int64 ("compat-status-max-media-attachments", "compat-status-max-media-attachments", "compat-status-max-media-attachments", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_CHARACTERS_RESERVED_PER_URL_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_CHARACTERS_RESERVED_PER_URL_PROPERTY] = g_param_spec_int ("compat-status-characters-reserved-per-url", "compat-status-characters-reserved-per-url", "compat-status-characters-reserved-per-url", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_MAX_CHARACTERS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_MAX_CHARACTERS_PROPERTY] = g_param_spec_int64 ("compat-status-max-characters", "compat-status-max-characters", "compat-status-max-characters", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_MAX_IMAGE_SIZE_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_MAX_IMAGE_SIZE_PROPERTY] = g_param_spec_int64 ("compat-status-max-image-size", "compat-status-max-image-size", "compat-status-max-image-size", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_MAX_VIDEO_SIZE_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_MAX_VIDEO_SIZE_PROPERTY] = g_param_spec_int64 ("compat-status-max-video-size", "compat-status-max-video-size", "compat-status-max-video-size", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_POLLS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_POLLS_PROPERTY] = g_param_spec_object ("compat-status-polls", "compat-status-polls", "compat-status-polls", TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY] = g_param_spec_int64 ("compat-status-poll-max-characters", "compat-status-poll-max-characters", "compat-status-poll-max-characters", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_OPTIONS_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_OPTIONS_PROPERTY] = g_param_spec_int64 ("compat-status-poll-max-options", "compat-status-poll-max-options", "compat-status-poll-max-options", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MIN_EXPIRATION_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MIN_EXPIRATION_PROPERTY] = g_param_spec_int64 ("compat-status-poll-min-expiration", "compat-status-poll-min-expiration", "compat-status-poll-min-expiration", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_EXPIRATION_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_EXPIRATION_PROPERTY] = g_param_spec_int64 ("compat-status-poll-max-expiration", "compat-status-poll-max-expiration", "compat-status-poll-max-expiration", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_INSTANCE_COMPAT_STATUS_REACTIONS_MAX_PROPERTY, tuba_api_instance_properties[TUBA_API_INSTANCE_COMPAT_STATUS_REACTIONS_MAX_PROPERTY] = g_param_spec_int64 ("compat-status-reactions-max", "compat-status-reactions-max", "compat-status-reactions-max", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
tuba_api_instance_instance_init (TubaAPIInstance * self,
                                 gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	TubaAPIInstanceV2ConfigurationAccountsCharLimits* _tmp2_;
	self->priv = tuba_api_instance_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_uri = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_title = _tmp1_;
	self->priv->_thumbnail = NULL;
	self->priv->_version = NULL;
	self->priv->_urls = NULL;
	self->priv->_configuration = NULL;
	self->priv->_max_toot_chars = (gint64) 0;
	self->priv->_poll_limits = NULL;
	self->priv->_upload_limit = (gint64) 0;
	self->priv->_pleroma = NULL;
	_tmp2_ = tuba_api_instance_v2_configuration_accounts_char_limits_new ();
	self->priv->_tuba_limits = _tmp2_;
	self->priv->_tuba_can_translate = FALSE;
	self->priv->_tuba_max_alt_chars = (gint64) 1500;
}

static void
tuba_api_instance_finalize (GObject * obj)
{
	TubaAPIInstance * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_INSTANCE, TubaAPIInstance);
	_g_free0 (self->priv->_uri);
	_g_free0 (self->priv->_title);
	_g_free0 (self->priv->_thumbnail);
	_g_free0 (self->priv->_version);
	_g_object_unref0 (self->priv->_urls);
	_g_object_unref0 (self->priv->_languages);
	_g_object_unref0 (self->priv->_configuration);
	_g_object_unref0 (self->priv->_poll_limits);
	_g_object_unref0 (self->priv->_pleroma);
	_g_object_unref0 (self->priv->_rules);
	_g_object_unref0 (self->priv->_tuba_limits);
	G_OBJECT_CLASS (tuba_api_instance_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_instance_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIInstanceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_instance_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIInstance), 0, (GInstanceInitFunc) tuba_api_instance_instance_init, NULL };
	GType tuba_api_instance_type_id;
	tuba_api_instance_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIInstance", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIInstance_private_offset = g_type_add_instance_private (tuba_api_instance_type_id, sizeof (TubaAPIInstancePrivate));
	return tuba_api_instance_type_id;
}

GType
tuba_api_instance_get_type (void)
{
	static GType tuba_api_instance_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_instance_type_id__once)) {
		GType tuba_api_instance_type_id;
		tuba_api_instance_type_id = tuba_api_instance_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_instance_type_id__once, tuba_api_instance_type_id);
	}
	return tuba_api_instance_type_id__once;
}

static void
_vala_tuba_api_instance_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	TubaAPIInstance * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_INSTANCE, TubaAPIInstance);
	switch (property_id) {
		case TUBA_API_INSTANCE_URI_PROPERTY:
		g_value_set_string (value, tuba_api_instance_get_uri (self));
		break;
		case TUBA_API_INSTANCE_TITLE_PROPERTY:
		g_value_set_string (value, tuba_api_instance_get_title (self));
		break;
		case TUBA_API_INSTANCE_THUMBNAIL_PROPERTY:
		g_value_set_string (value, tuba_api_instance_get_thumbnail (self));
		break;
		case TUBA_API_INSTANCE_VERSION_PROPERTY:
		g_value_set_string (value, tuba_api_instance_get_version (self));
		break;
		case TUBA_API_INSTANCE_URLS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_urls (self));
		break;
		case TUBA_API_INSTANCE_LANGUAGES_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_languages (self));
		break;
		case TUBA_API_INSTANCE_CONFIGURATION_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_configuration (self));
		break;
		case TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_max_toot_chars (self));
		break;
		case TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_poll_limits (self));
		break;
		case TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_upload_limit (self));
		break;
		case TUBA_API_INSTANCE_PLEROMA_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_pleroma (self));
		break;
		case TUBA_API_INSTANCE_RULES_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_rules (self));
		break;
		case TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_tuba_limits (self));
		break;
		case TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY:
		g_value_set_boolean (value, tuba_api_instance_get_tuba_can_translate (self));
		break;
		case TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_tuba_max_alt_chars (self));
		break;
		case TUBA_API_INSTANCE_SUPPORTS_QUOTE_POSTING_PROPERTY:
		g_value_set_boolean (value, tuba_api_instance_get_supports_quote_posting (self));
		break;
		case TUBA_API_INSTANCE_SUPPORTS_BUBBLE_PROPERTY:
		g_value_set_boolean (value, tuba_api_instance_get_supports_bubble (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_SUPPORTED_MIME_TYPES_PROPERTY:
		{
			int length;
			g_value_set_boxed (value, tuba_api_instance_get_compat_supported_mime_types (self, &length));
		}
		break;
		case TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_MAX_FIELDS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_fields_limits_max_fields (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_NAME_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_fields_limits_name_length (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_FIELDS_LIMITS_VALUE_LENGTH_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_fields_limits_value_length (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_MAX_MEDIA_ATTACHMENTS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_max_media_attachments (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_CHARACTERS_RESERVED_PER_URL_PROPERTY:
		g_value_set_int (value, tuba_api_instance_get_compat_status_characters_reserved_per_url (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_MAX_CHARACTERS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_max_characters (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_MAX_IMAGE_SIZE_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_max_image_size (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_MAX_VIDEO_SIZE_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_max_video_size (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_POLLS_PROPERTY:
		g_value_set_object (value, tuba_api_instance_get_compat_status_polls (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_poll_max_characters (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_OPTIONS_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_poll_max_options (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MIN_EXPIRATION_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_poll_min_expiration (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_POLL_MAX_EXPIRATION_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_poll_max_expiration (self));
		break;
		case TUBA_API_INSTANCE_COMPAT_STATUS_REACTIONS_MAX_PROPERTY:
		g_value_set_int64 (value, tuba_api_instance_get_compat_status_reactions_max (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_instance_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	TubaAPIInstance * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_INSTANCE, TubaAPIInstance);
	switch (property_id) {
		case TUBA_API_INSTANCE_URI_PROPERTY:
		tuba_api_instance_set_uri (self, g_value_get_string (value));
		break;
		case TUBA_API_INSTANCE_TITLE_PROPERTY:
		tuba_api_instance_set_title (self, g_value_get_string (value));
		break;
		case TUBA_API_INSTANCE_THUMBNAIL_PROPERTY:
		tuba_api_instance_set_thumbnail (self, g_value_get_string (value));
		break;
		case TUBA_API_INSTANCE_VERSION_PROPERTY:
		tuba_api_instance_set_version (self, g_value_get_string (value));
		break;
		case TUBA_API_INSTANCE_URLS_PROPERTY:
		tuba_api_instance_set_urls (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_LANGUAGES_PROPERTY:
		tuba_api_instance_set_languages (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_CONFIGURATION_PROPERTY:
		tuba_api_instance_set_configuration (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_MAX_TOOT_CHARS_PROPERTY:
		tuba_api_instance_set_max_toot_chars (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_POLL_LIMITS_PROPERTY:
		tuba_api_instance_set_poll_limits (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_UPLOAD_LIMIT_PROPERTY:
		tuba_api_instance_set_upload_limit (self, g_value_get_int64 (value));
		break;
		case TUBA_API_INSTANCE_PLEROMA_PROPERTY:
		tuba_api_instance_set_pleroma (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_RULES_PROPERTY:
		tuba_api_instance_set_rules (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_TUBA_LIMITS_PROPERTY:
		tuba_api_instance_set_tuba_limits (self, g_value_get_object (value));
		break;
		case TUBA_API_INSTANCE_TUBA_CAN_TRANSLATE_PROPERTY:
		tuba_api_instance_set_tuba_can_translate (self, g_value_get_boolean (value));
		break;
		case TUBA_API_INSTANCE_TUBA_MAX_ALT_CHARS_PROPERTY:
		tuba_api_instance_set_tuba_max_alt_chars (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

